pub struct DAG<N: Network> { /* private fields */ }Expand description
Maintains a directed acyclic graph (DAG) of certificates, from which we build a totally-ordered blockchain.
The DAG is updated in rounds, where each validator adds at most one new batch. Certificates older than GC are removed, as they are not longer needed.
Invariants:
- For each entry in
graphthere is a corresponding certificate ID inrecent_committed_ids. last_committed_round, if >0, is equal to the largest key inrecent_commit_ids.
Implementations
Sourceimpl<N: Network> DAG<N>
impl<N: Network> DAG<N>
Sourcepub const fn graph(
&self,
) -> &BTreeMap<u64, HashMap<Address<N>, BatchCertificate<N>>>
pub const fn graph( &self, ) -> &BTreeMap<u64, HashMap<Address<N>, BatchCertificate<N>>>
Returns the DAG.
Sourcepub const fn last_committed_round(&self) -> u64
pub const fn last_committed_round(&self) -> u64
Returns the latest round a certificate was committed to.
Sourcepub fn is_recently_committed(
&self,
round: u64,
certificate_id: Field<N>,
) -> bool
pub fn is_recently_committed( &self, round: u64, certificate_id: Field<N>, ) -> bool
Returns true if the given certificate ID was recently committed.
Sourcepub fn contains_certificate_in_round(
&self,
round: u64,
certificate_id: Field<N>,
) -> bool
pub fn contains_certificate_in_round( &self, round: u64, certificate_id: Field<N>, ) -> bool
Returns true if the given certificate ID exists in the given round.
Returns the batch certificate for the given round and author.
Sourcepub fn get_certificate_for_round_with_id(
&self,
round: u64,
certificate_id: Field<N>,
) -> Option<BatchCertificate<N>>
pub fn get_certificate_for_round_with_id( &self, round: u64, certificate_id: Field<N>, ) -> Option<BatchCertificate<N>>
Returns the batch certificate for the given round and certificate ID.
Sourcepub fn get_certificates_for_round(
&self,
round: u64,
) -> Option<HashMap<Address<N>, BatchCertificate<N>>>
pub fn get_certificates_for_round( &self, round: u64, ) -> Option<HashMap<Address<N>, BatchCertificate<N>>>
Returns the batch certificates for the given round.
Sourcepub fn insert(&mut self, certificate: BatchCertificate<N>)
pub fn insert(&mut self, certificate: BatchCertificate<N>)
Inserts a certificate into the DAG.
Sourcepub fn commit(&mut self, certificate: &BatchCertificate<N>, max_gc_rounds: u64)
pub fn commit(&mut self, certificate: &BatchCertificate<N>, max_gc_rounds: u64)
Commits a certificate, removing all certificates for this author at or before this round from the DAG.