Pending

Struct Pending 

pub struct Pending<T: PartialEq + Eq + Hash, V: Clone> { /* private fields */ }

Implementations

Source

impl<T: Copy + Clone + PartialEq + Eq + Hash, V: Clone> Pending<T, V>

pub fn new() -> Self

Initializes a new instance of the pending queue.

pub fn is_empty(&self) -> bool

Returns true if the pending queue is empty.

pub fn len(&self) -> usize

Returns the number of pending in the pending queue.

pub fn contains(&self, item: impl Into<T>) -> bool

Returns true if the pending queue contains the specified item.

pub fn contains_peer(&self, item: impl Into<T>, peer_ip: SocketAddr) -> bool

Returns true if the pending queue contains the specified item for the specified peer IP.

pub fn contains_peer_with_sent_request( &self, item: impl Into<T>, peer_ip: SocketAddr, ) -> bool

Returns true if the pending queue contains the specified item for the specified peer IP with a sent request.

pub fn get_peers(&self, item: impl Into<T>) -> Option<HashSet<SocketAddr>>

Returns the peer IPs for the specified item.

pub fn num_callbacks(&self, item: impl Into<T>) -> usize

Returns the number of pending callbacks for the specified item.

pub fn num_sent_requests(&self, item: impl Into<T>) -> usize

Returns the number of pending sent requests for the specified item.

pub fn insert( &self, item: impl Into<T>, peer_ip: SocketAddr, callback: Option<(Sender<V>, bool)>, ) -> bool

Inserts the specified item and peer IP to the pending queue, returning true if the peer IP was newly-inserted into the entry for the item.

In addition, an optional callback may be provided, that is triggered upon removal. Note: The callback, if provided, is always inserted into the callback queue.

pub fn remove( &self, item: impl Into<T>, callback_value: Option<V>, ) -> Option<HashSet<SocketAddr>>

Removes the specified item from the pending queue. If the item exists and is removed, the peer IPs are returned. If the item does not exist, None is returned.

pub fn clear_expired_callbacks_for_item(&self, now: i64, item: impl Into<T>)

Removes the callbacks for the specified item that have expired.

pub fn clear_expired_callbacks(&self)

Removes the callbacks for all items have that expired.