BFT

Struct BFT 

pub struct BFT<N: Network> { /* private fields */ }

Implementations

Source

impl<N: Network> BFT<N>

pub fn new( account: Account<N>, storage: Storage<N>, ledger: Arc<dyn LedgerService<N>>, block_sync: Arc<BlockSync<N>>, ip: Option<SocketAddr>, trusted_validators: &[SocketAddr], trusted_peers_only: bool, node_data_dir: NodeDataDir, dev: Option<u16>, ) -> Result<Self>

Initializes a new instance of the BFT.

pub async fn run( &mut self, ping: Option<Arc<Ping<N>>>, consensus_sender: Option<ConsensusSender<N>>, primary_sender: PrimarySender<N>, primary_receiver: PrimaryReceiver<N>, ) -> Result<()>

Run the BFT instance.

This will return as soon as all required tasks are spawned. The function must not be called more than once per instance.

pub fn is_synced(&self) -> bool

Returns true if the primary is synced.

pub const fn primary(&self) -> &Primary<N>

Returns the primary.

pub const fn storage(&self) -> &Storage<N>

Returns the storage.

pub fn ledger(&self) -> &Arc<dyn LedgerService<N>>

Returns the ledger.

pub fn leader(&self) -> Option<Address<N>>

Returns the leader of the current even round, if one was present.

pub const fn leader_certificate( &self, ) -> &Arc<RwLock<Option<BatchCertificate<N>>>>

Returns the certificate of the leader from the current even round, if one was present.

Source

impl<N: Network> BFT<N>

pub fn num_unconfirmed_transmissions(&self) -> usize

Returns the number of unconfirmed transmissions.

pub fn num_unconfirmed_ratifications(&self) -> usize

Returns the number of unconfirmed ratifications.

pub fn num_unconfirmed_solutions(&self) -> usize

Returns the number of solutions.

pub fn num_unconfirmed_transactions(&self) -> usize

Returns the number of unconfirmed transactions.

Source

impl<N: Network> BFT<N>

pub fn worker_transmission_ids( &self, ) -> impl '_ + Iterator<Item = TransmissionID<N>>

Returns the worker transmission IDs.

pub fn worker_transmissions( &self, ) -> impl '_ + Iterator<Item = (TransmissionID<N>, Transmission<N>)>

Returns the worker transmissions.

pub fn worker_solutions( &self, ) -> impl '_ + Iterator<Item = (SolutionID<N>, Data<Solution<N>>)>

Returns the worker solutions.

pub fn worker_transactions( &self, ) -> impl '_ + Iterator<Item = (N::TransactionID, Data<Transaction<N>>)>

Returns the worker transactions.

Source

impl<N: Network> BFT<N>

pub async fn shut_down(&self)

Shuts down the BFT.