pub struct Gateway<N: Network>(/* private fields */);Expand description
The gateway maintains connections to other validators. For connections with clients and provers, the Router logic is used.
Implementations
Sourceimpl<N: Network> Gateway<N>
impl<N: Network> Gateway<N>
Sourcepub fn new(
account: Account<N>,
storage: Storage<N>,
ledger: Arc<dyn LedgerService<N>>,
ip: Option<SocketAddr>,
trusted_validators: &[SocketAddr],
trusted_peers_only: bool,
node_data_dir: NodeDataDir,
dev: Option<u16>,
) -> Result<Self>
pub fn new( account: Account<N>, storage: Storage<N>, ledger: Arc<dyn LedgerService<N>>, ip: Option<SocketAddr>, trusted_validators: &[SocketAddr], trusted_peers_only: bool, node_data_dir: NodeDataDir, dev: Option<u16>, ) -> Result<Self>
Initializes a new gateway.
Sourcepub async fn run(
&self,
primary_sender: PrimarySender<N>,
worker_senders: IndexMap<u8, WorkerSender<N>>,
sync_sender: Option<SyncSender<N>>,
)
pub async fn run( &self, primary_sender: PrimarySender<N>, worker_senders: IndexMap<u8, WorkerSender<N>>, sync_sender: Option<SyncSender<N>>, )
Run the gateway.
Sourceimpl<N: Network> Gateway<N>
impl<N: Network> Gateway<N>
Sourcepub fn resolve_to_listener(
&self,
connected_addr: &SocketAddr,
) -> Option<SocketAddr>
pub fn resolve_to_listener( &self, connected_addr: &SocketAddr, ) -> Option<SocketAddr>
Returns the listener IP address from the (ambiguous) peer address.
Sourcepub fn primary_sender(&self) -> &PrimarySender<N>
pub fn primary_sender(&self) -> &PrimarySender<N>
Returns the primary sender.
Sourcepub fn num_workers(&self) -> u8
pub fn num_workers(&self) -> u8
Returns the number of workers.
Sourcepub fn get_worker_sender(&self, worker_id: u8) -> Option<&WorkerSender<N>>
pub fn get_worker_sender(&self, worker_id: u8) -> Option<&WorkerSender<N>>
Returns the worker sender for the given worker ID.
Returns true if the given peer IP is an authorized validator.
Returns true if the given address is an authorized validator.
Sourcepub fn connected_addresses(&self) -> HashSet<Address<N>>
pub fn connected_addresses(&self) -> HashSet<Address<N>>
Returns the list of connected addresses.