pub type ProposedBatch<N> = RwLock<ProposedBatchState<N>>;Expand description
A helper type to keep track of the state of the primary’s batch proposal.
Aliased Type
pub struct ProposedBatch<N> { /* private fields */ }pub type ProposedBatch<N> = RwLock<ProposedBatchState<N>>;A helper type to keep track of the state of the primary’s batch proposal.
pub struct ProposedBatch<N> { /* private fields */ }