A worker’s main role is maintaining a queue of verified (“ready”) transmissions,
which will eventually be fetched by the primary when the primary generates a new batch.
The time a primary waits between attempts to create a new batch (only relevant after MIN_BATCH_DELAY has passed).
This only serves as a failsafe in case the task does not get woken up through other means.
Lowering it too much would be wasteful.
The maximum time allowed for the leader to send their certificate.
After this time, the node will consider the leader as failed and try to advance the round without it.
The maximum difference allowed between our local time and a certificate’s timestamp, for the node to sign the certificate.
This prevents malicious actors from proposing certificates with timestamps that are too log or too far in the future)
w
The minimum time that needs to elapse between two consecutive batch proposals.
This creates a lower bound on the block interval, and ensures the network will not be overwhelmed with too many blocks/certificates.
The interval at which each primary broadcasts a ping to every other node.
Note: If this is updated, be sure to update MAX_BLOCKS_BEHIND to correspond properly.