pub struct BFT<N: Network> { /* private fields */ }Implementations
Sourceimpl<N: Network> BFT<N>
impl<N: Network> BFT<N>
Sourcepub fn new(
account: Account<N>,
storage: Storage<N>,
ledger: Arc<dyn LedgerService<N>>,
block_sync: Arc<BlockSync<N>>,
ip: Option<SocketAddr>,
trusted_validators: &[SocketAddr],
trusted_peers_only: bool,
node_data_dir: NodeDataDir,
dev: Option<u16>,
) -> Result<Self>
pub fn new( account: Account<N>, storage: Storage<N>, ledger: Arc<dyn LedgerService<N>>, block_sync: Arc<BlockSync<N>>, ip: Option<SocketAddr>, trusted_validators: &[SocketAddr], trusted_peers_only: bool, node_data_dir: NodeDataDir, dev: Option<u16>, ) -> Result<Self>
Initializes a new instance of the BFT.
Sourcepub async fn run(
&mut self,
ping: Option<Arc<Ping<N>>>,
consensus_sender: Option<ConsensusSender<N>>,
primary_sender: PrimarySender<N>,
primary_receiver: PrimaryReceiver<N>,
) -> Result<()>
pub async fn run( &mut self, ping: Option<Arc<Ping<N>>>, consensus_sender: Option<ConsensusSender<N>>, primary_sender: PrimarySender<N>, primary_receiver: PrimaryReceiver<N>, ) -> Result<()>
Run the BFT instance.
This will return as soon as all required tasks are spawned. The function must not be called more than once per instance.
Sourcepub fn ledger(&self) -> &Arc<dyn LedgerService<N>> ⓘ
pub fn ledger(&self) -> &Arc<dyn LedgerService<N>> ⓘ
Returns the ledger.
Sourcepub fn leader(&self) -> Option<Address<N>>
pub fn leader(&self) -> Option<Address<N>>
Returns the leader of the current even round, if one was present.
Sourcepub const fn leader_certificate(
&self,
) -> &Arc<RwLock<Option<BatchCertificate<N>>>> ⓘ
pub const fn leader_certificate( &self, ) -> &Arc<RwLock<Option<BatchCertificate<N>>>> ⓘ
Returns the certificate of the leader from the current even round, if one was present.
Sourceimpl<N: Network> BFT<N>
impl<N: Network> BFT<N>
Sourcepub fn num_unconfirmed_transmissions(&self) -> usize
pub fn num_unconfirmed_transmissions(&self) -> usize
Returns the number of unconfirmed transmissions.
Sourcepub fn num_unconfirmed_ratifications(&self) -> usize
pub fn num_unconfirmed_ratifications(&self) -> usize
Returns the number of unconfirmed ratifications.
Sourcepub fn num_unconfirmed_solutions(&self) -> usize
pub fn num_unconfirmed_solutions(&self) -> usize
Returns the number of solutions.
Sourcepub fn num_unconfirmed_transactions(&self) -> usize
pub fn num_unconfirmed_transactions(&self) -> usize
Returns the number of unconfirmed transactions.
Sourceimpl<N: Network> BFT<N>
impl<N: Network> BFT<N>
Sourcepub fn worker_transmission_ids(
&self,
) -> impl '_ + Iterator<Item = TransmissionID<N>>
pub fn worker_transmission_ids( &self, ) -> impl '_ + Iterator<Item = TransmissionID<N>>
Returns the worker transmission IDs.
Sourcepub fn worker_transmissions(
&self,
) -> impl '_ + Iterator<Item = (TransmissionID<N>, Transmission<N>)>
pub fn worker_transmissions( &self, ) -> impl '_ + Iterator<Item = (TransmissionID<N>, Transmission<N>)>
Returns the worker transmissions.
Sourcepub fn worker_solutions(
&self,
) -> impl '_ + Iterator<Item = (SolutionID<N>, Data<Solution<N>>)>
pub fn worker_solutions( &self, ) -> impl '_ + Iterator<Item = (SolutionID<N>, Data<Solution<N>>)>
Returns the worker solutions.
Sourcepub fn worker_transactions(
&self,
) -> impl '_ + Iterator<Item = (N::TransactionID, Data<Transaction<N>>)>
pub fn worker_transactions( &self, ) -> impl '_ + Iterator<Item = (N::TransactionID, Data<Transaction<N>>)>
Returns the worker transactions.